@@ -24,13 +24,13 @@ def get_contract_config(chainID: int) -> ContractConfig:
     """
     CONFIG = {
         137: ContractConfig(
-            exchange="0xfffd6f0dB1ec30A58884B23546B4F1bB333f818f",
+            exchange="0x4bFb41d5B3570DeFd03C39a9A4D8dE6Bd8B8982E",
             executor="0xb2a29463Df393a4CAef36541544715e6B48b80B7",
             collateral="0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
             conditional="0x4D97DCd97eC945f40cF65F87097ACe5EA0476045",
         ),
         80001: ContractConfig(
-            exchange="0xfffd6f0dB1ec30A58884B23546B4F1bB333f818f",
+            exchange="0x4bFb41d5B3570DeFd03C39a9A4D8dE6Bd8B8982E",
             executor="0xb2a29463Df393a4CAef36541544715e6B48b80B7",
             collateral="0x2E8DCfE708D44ae2e406a1c02DFE2Fa13012f961",
             conditional="0x7D8610E9567d2a6C9FBf66a5A13E9Ba8bb120d43",
